@@ -77,7 +77,7 @@ class TestContextsClient(object):
             client = dialogflow_v2.ContextsClient()
 
         # Setup Request
-        parent = client.session_path("[PROJECT]", "[SESSION]")
+        parent = "parent-995424086"
 
         paged_list_response = client.list_contexts(parent)
         resources = list(paged_list_response)
@@ -98,7 +98,7 @@ class TestContextsClient(object):
             client = dialogflow_v2.ContextsClient()
 
         # Setup request
-        parent = client.session_path("[PROJECT]", "[SESSION]")
+        parent = "parent-995424086"
 
         paged_list_response = client.list_contexts(parent)
         with pytest.raises(CustomException):
@@ -119,7 +119,7 @@ class TestContextsClient(object):
             client = dialogflow_v2.ContextsClient()
 
         # Setup Request
-        name = client.context_path("[PROJECT]", "[SESSION]", "[CONTEXT]")
+        name = "name3373707"
 
         response = client.get_context(name)
         assert expected_response == response
@@ -138,7 +138,7 @@ class TestContextsClient(object):
             client = dialogflow_v2.ContextsClient()
 
         # Setup request
-        name = client.context_path("[PROJECT]", "[SESSION]", "[CONTEXT]")
+        name = "name3373707"
 
         with pytest.raises(CustomException):
             client.get_context(name)
@@ -158,7 +158,7 @@ class TestContextsClient(object):
             client = dialogflow_v2.ContextsClient()
 
         # Setup Request
-        parent = client.session_path("[PROJECT]", "[SESSION]")
+        parent = "parent-995424086"
         context = {}
 
         response = client.create_context(parent, context)
@@ -180,7 +180,7 @@ class TestContextsClient(object):
             client = dialogflow_v2.ContextsClient()
 
         # Setup request
-        parent = client.session_path("[PROJECT]", "[SESSION]")
+        parent = "parent-995424086"
         context = {}
 
         with pytest.raises(CustomException):
@@ -233,7 +233,7 @@ class TestContextsClient(object):
             client = dialogflow_v2.ContextsClient()
 
         # Setup Request
-        name = client.context_path("[PROJECT]", "[SESSION]", "[CONTEXT]")
+        name = "name3373707"
 
         client.delete_context(name)
 
@@ -251,7 +251,7 @@ class TestContextsClient(object):
             client = dialogflow_v2.ContextsClient()
 
         # Setup request
-        name = client.context_path("[PROJECT]", "[SESSION]", "[CONTEXT]")
+        name = "name3373707"
 
         with pytest.raises(CustomException):
             client.delete_context(name)
@@ -264,7 +264,7 @@ class TestContextsClient(object):
             client = dialogflow_v2.ContextsClient()
 
         # Setup Request
-        parent = client.session_path("[PROJECT]", "[SESSION]")
+        parent = "parent-995424086"
 
         client.delete_all_contexts(parent)
 
@@ -282,7 +282,7 @@ class TestContextsClient(object):
             client = dialogflow_v2.ContextsClient()
 
         # Setup request
-        parent = client.session_path("[PROJECT]", "[SESSION]")
+        parent = "parent-995424086"
 
         with pytest.raises(CustomException):
             client.delete_all_contexts(parent)
